@@ -54,8 +54,8 @@ class SimpleAPI(object):
 
     def get_response(self, request):
         response = None
-        self.get = request.GET
-        self.post = request.POST
+        self.get = request.GET.copy()
+        self.post = request.POST.copy()
         if self.pre_validate():
             #if self.secret_key:
             #    setattr(self, "access_token", CharVariable())
